cocos.audio.SDL.darwin module — cocos v0.6.5 documentation

# cocos.audio.SDL.darwin module

System Message: WARNING/2 (`F:\dev\cocos2017\docgen\api\cocos.audio.SDL.darwin.txt`, line 4)

autodoc: failed to import module ‘cocos.audio.SDL.darwin’; the following exception was raised: Traceback (most recent call last): File “c:\python36\lib\site-packages\sphinx\ext\autodoc.py”, line 657, in import_object __import__(self.modname) File “F:\dev\cocos2017\cocos\audio\SDL\darwin.py”, line 18, in <module> from Foundation import * ModuleNotFoundError: No module named ‘Foundation’